# CHANGELOG
## 0.4.0 (2024-07-01)


### :construction_worker: Updated Continuous Integration

* add 0.x branch pattern — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`5d606c8`](https://github.com/OZI-Project/ozi-spec/commit/5d606c850a9316b1b9f7ecf0cc7c9897b82f6fa1))


### Feature


* feat: tag OZI 1.14 ([`b6cb028`](https://github.com/OZI-Project/ozi-spec/commit/b6cb0285901d95512e7545c06edd7f2c539c4125))


### Unknown


* Update requirements.in — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt; ([`a0bcce3`](https://github.com/OZI-Project/ozi-spec/commit/a0bcce34cf6ba9abfd1bdc0685ae9d6c62a7c742))

## 0.3.0 (2024-07-01)


### Feature


* feat: init from OZI 1.13.31 spec submodule source ([`434d1db`](https://github.com/OZI-Project/ozi-spec/commit/434d1db4aff6652cd9b88002d18c4d14f55cbd0d))
